@@ -1,6 +1,6 @@
 from dataclasses import dataclass, field
 from enum import Enum, unique
-from typing import Optional
+from typing import Any, Optional
 
 from notification_server_connector.utils.current_timestamp import get_current_timestamp_ms
 
@@ -9,6 +9,7 @@ from notification_server_connector.utils.current_timestamp import get_current_ti
 class SourceTypes(str, Enum):
     thread = 'thread'
     comment = 'comment'
+    community_summary = 'community_summary'
 
 
 @dataclass
@@ -18,8 +19,12 @@ class Notification:
     portal_id: int
     portal_member_id: int
     title: str
-    message: str
+    message: str = ''
     parent_id: Optional[int] = None
     parent_name: Optional[str] = None
     notification_receivers: list[int] = field(default_factory=list)
     created_at: int = field(default_factory=get_current_timestamp_ms)
+    fcm_topic: Optional[str] = None
+
+    args: Optional[dict[str, Any]] = None
+    children: list["Notification"] = field(default_factory=list)
