@@ -4,8 +4,8 @@ from aiokafka import AIOKafkaProducer
 
 from async_tools import AsyncOnStart, AsyncOnStop
 
-from models.notification import Notification
-from utils.abstract_encoder import AbstractEncoder
+from notification_server_connector.models.notification import Notification
+from notification_server_connector.utils.abstract_encoder import AbstractEncoder
 
 
 logger = Logger(__name__)
